@@ -336,7 +336,17 @@ class Heatmiser(HeatmiserTransport):
             else:
                 raise Exception("'"+name+"' invalid value '"+str(value)+"'\n" +
                                 "Valid values: 'Lock' or 'Unlock'")
-            self.set_dcb(22,bytearray([value]))                            
+            self.set_dcb(22,bytearray([value]))
+        elif(name == "run_mode"):
+            if(value == "Frost protection mode"):
+                value = 1
+            elif(value == "Heating mode (normal mode)"):
+                value = 0
+            else:
+                raise Exception("'"+name+"' invalid value '"+str(value)+"'\n" +
+                                "Valid values: 'Frost protection mode' or " +
+                                "'Heating mode (normal mode)'")
+            self.set_dcb(23,bytearray([value]))                            
         else:
             raise Exception("'"+name+"' not supported to be set")
 
